# Change Log

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Semantic Versioning](http://semver.org/).

## [0.3.0] - 2025-12-09

- fix: update saving of status of profiled parameters.
- feature: add auto-versioning.
- feature: add auto-building.

## [0.2] - 2025-07-29

- First PYPI version

## [0.1] - 2025-07-26

The prerelease version
